@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # coding: utf-8
 
 # Copyright (c) 2012, Machinalis S.R.L.
@@ -12,12 +11,11 @@
 Settings.
 """
 
-# Freeling config
-USE_FREELING = False
-FREELING_CMD = ""  # Only set if USE_FREELING it's True
+# Generated query language
+LANGUAGE = "sparql"
 
 # NLTK config
-NLTK_DATA_PATH = ["/home/rafael/deploy/nltk/data"]  # List of paths with NLTK data
+NLTK_DATA_PATH = []  # List of paths with NLTK data
 
 # Encoding config
 DEFAULT_ENCODING = "utf-8"
