@@ -12,9 +12,8 @@
 Settings for testapp quepy.
 """
 
-USE_FREELING = False
-FREELING_CMD = ''
-NLTK_DATA_PATH = ["/home/rafael/deploy/nltk/data"]
+LANGUAGE = "sparql"
+NLTK_DATA_PATH = []
 SPARQL_PREAMBLE = '''
 PREFIX owl: <http://www.w3.org/2002/07/owl#>
 PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
